@@ -50,67 +50,71 @@
 #' bayesfactor_models(lm2, lm3, lm4, denominator = lm1) # same result
 #' bayesfactor_models(lm1, lm2, lm3, lm4, denominator = lm1) # same result
 #'
+#' \dontrun{
 #' # With lmerMod objects:
 #' # ---------------------
-#' library(lme4)
-#' lmer1 <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
-#' lmer2 <- lmer(Sepal.Length ~ Petal.Length + (Petal.Length | Species), data = iris)
-#' lmer3 <- lmer(
-#'   Sepal.Length ~ Petal.Length + (Petal.Length | Species) + (1 | Petal.Width),
-#'   data = iris
-#' )
-#' bayesfactor_models(lmer1, lmer2, lmer3, denominator = 1)
-#' bayesfactor_models(lmer1, lmer2, lmer3, denominator = lmer1)
-#' \dontrun{
+#' if (require("lme4")) {
+#'   lmer1 <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
+#'   lmer2 <- lmer(Sepal.Length ~ Petal.Length + (Petal.Length | Species), data = iris)
+#'   lmer3 <- lmer(
+#'     Sepal.Length ~ Petal.Length + (Petal.Length | Species) + (1 | Petal.Width),
+#'     data = iris
+#'   )
+#'   bayesfactor_models(lmer1, lmer2, lmer3, denominator = 1)
+#'   bayesfactor_models(lmer1, lmer2, lmer3, denominator = lmer1)
+#' }
+#'
 #' # rstanarm models
 #' # ---------------------
 #' # (note that a unique diagnostic_file MUST be specified in order to work)
-#' library(rstanarm)
-#' stan_m0 <- stan_glm(Sepal.Length ~ 1,
-#'   data = iris,
-#'   family = gaussian(),
-#'   diagnostic_file = file.path(tempdir(), "df0.csv")
-#' )
-#' stan_m1 <- stan_glm(Sepal.Length ~ Species,
-#'   data = iris,
-#'   family = gaussian(),
-#'   diagnostic_file = file.path(tempdir(), "df1.csv")
-#' )
-#' stan_m2 <- stan_glm(Sepal.Length ~ Species + Petal.Length,
-#'   data = iris,
-#'   family = gaussian(),
-#'   diagnostic_file = file.path(tempdir(), "df2.csv")
-#' )
-#' bayesfactor_models(stan_m1, stan_m2, denominator = stan_m0)
+#' if (require("rstanarm")) {
+#'   stan_m0 <- stan_glm(Sepal.Length ~ 1,
+#'     data = iris,
+#'     family = gaussian(),
+#'     diagnostic_file = file.path(tempdir(), "df0.csv")
+#'   )
+#'   stan_m1 <- stan_glm(Sepal.Length ~ Species,
+#'     data = iris,
+#'     family = gaussian(),
+#'     diagnostic_file = file.path(tempdir(), "df1.csv")
+#'   )
+#'   stan_m2 <- stan_glm(Sepal.Length ~ Species + Petal.Length,
+#'     data = iris,
+#'     family = gaussian(),
+#'     diagnostic_file = file.path(tempdir(), "df2.csv")
+#'   )
+#'   bayesfactor_models(stan_m1, stan_m2, denominator = stan_m0)
+#' }
 #'
 #'
 #' # brms models
 #' # --------------------
 #' # (note the save_all_pars MUST be set to TRUE in order to work)
-#' library(brms)
-#' brm1 <- brm(Sepal.Length ~ 1, data = iris, save_all_pars = TRUE)
-#' brm2 <- brm(Sepal.Length ~ Species, data = iris, save_all_pars = TRUE)
-#' brm3 <- brm(
-#'   Sepal.Length ~ Species + Petal.Length,
-#'   data = iris,
-#'   save_all_pars = TRUE
-#' )
+#' if (require("brms")) {
+#'   brm1 <- brm(Sepal.Length ~ 1, data = iris, save_all_pars = TRUE)
+#'   brm2 <- brm(Sepal.Length ~ Species, data = iris, save_all_pars = TRUE)
+#'   brm3 <- brm(
+#'     Sepal.Length ~ Species + Petal.Length,
+#'     data = iris,
+#'     save_all_pars = TRUE
+#'   )
 #'
-#' bayesfactor_models(brm1, brm2, brm3, denominator = 1)
+#'   bayesfactor_models(brm1, brm2, brm3, denominator = 1)
+#' }
 #'
 #'
 #' # BayesFactor
 #' # ---------------------------
-#' library(BayesFactor)
-#' data(puzzles)
-#' BF <- anovaBF(RT ~ shape * color + ID,
-#'   data = puzzles,
-#'   whichRandom = "ID", progress = FALSE
-#' )
-#' BF
-#' bayesfactor_models(BF) # basically the same
+#' if (require("BayesFactor")) {
+#'   data(puzzles)
+#'   BF <- anovaBF(RT ~ shape * color + ID,
+#'     data = puzzles,
+#'     whichRandom = "ID", progress = FALSE
+#'   )
+#'   BF
+#'   bayesfactor_models(BF) # basically the same
+#' }
 #' }
-#'
 #' @references
 #' \itemize{
 #'   \item Gronau, Q. F., Wagenmakers, E. J., Heck, D. W., and Matzke, D. (2019). A simple method for comparing complex models: Bayesian model comparison for hierarchical multinomial processing tree models using Warp-III bridge sampling. Psychometrika, 84(1), 261-284.
@@ -135,7 +139,7 @@ bf_models <- bayesfactor_models
 bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   # Organize the models and their names
   mods <- list(...)
-  mnames <- sapply(match.call(expand.dots = F)$`...`, .safe_deparse)
+  mnames <- sapply(match.call(expand.dots = FALSE)$`...`, .safe_deparse)
 
   if (!is.numeric(denominator)) {
     model_name <- .safe_deparse(match.call()[["denominator"]])
@@ -216,7 +220,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
   if (!is.numeric(denominator)) {
     model_name <- .safe_deparse(match.call()[["denominator"]])
-    arg_names <- sapply(match.call(expand.dots = F)$`...`, .safe_deparse)
+    arg_names <- sapply(match.call(expand.dots = FALSE)$`...`, .safe_deparse)
     denominator_model <- which(arg_names == model_name)
 
     if (length(denominator_model) == 0) {
